==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/PropCycle.h <==
// public final class soot.jimple.spark.solver.PropCycle

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 12e738d2eaa79a15 soot_jimple_spark_solver_PropCycle
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropCycle_H_
#define _JC_soot_jimple_spark_solver_PropCycle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Integer$object;
struct _jc_java_util_ArrayList$object;
struct _jc_soot_jimple_spark_internal_TypeManager$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;
struct _jc_soot_jimple_spark_solver_PropCycle$object;
struct _jc_soot_util_LargeNumberedMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropCycle$sub_refs	_jc_soot_jimple_spark_solver_PropCycle$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs	_jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$refs	_jc_soot_jimple_spark_solver_PropCycle$refs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$nonrefs	_jc_soot_jimple_spark_solver_PropCycle$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$object	_jc_soot_jimple_spark_solver_PropCycle$object;

typedef const struct _jc_soot_jimple_spark_solver_PropCycle$vmethods	_jc_soot_jimple_spark_solver_PropCycle$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropCycle$vtable	_jc_soot_jimple_spark_solver_PropCycle$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropCycle$vtype	_jc_soot_jimple_spark_solver_PropCycle$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropCycle$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *, struct _jc_soot_jimple_spark_pag_PAG$object *);

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropCycle$method$computeP2Set$16456f168b4b3df5(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_java_util_ArrayList$object *);
extern void _jc_soot_jimple_spark_solver_PropCycle$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropCycle$method_info$computeP2Set$16456f168b4b3df5;
extern _jc_method _jc_soot_jimple_spark_solver_PropCycle$method_info$propagate$430f3309bbb43666;

// Static methods
extern struct _jc_soot_jimple_spark_pag_PAG$object *_jc_soot_jimple_spark_solver_PropCycle$method$access__24000$801edc7b9b5ca5ed(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *);

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropCycle$vmethods {
	jboolean	(*computeP2Set$16456f168b4b3df5)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_java_util_ArrayList$object *);
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropCycle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropCycle$vmethods	soot_jimple_spark_solver_PropCycle;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropCycle$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropCycle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropCycle$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
	struct _jc_java_lang_Integer$object	*currentIteration;
	struct _jc_soot_util_LargeNumberedMap$object	*varNodeToIteration;
	struct _jc_soot_jimple_spark_internal_TypeManager$object	*typeManager;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropCycle$refs {
    _jc_soot_jimple_spark_solver_PropCycle$sub_refs	soot_jimple_spark_solver_PropCycle;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropCycle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs	soot_jimple_spark_solver_PropCycle;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropCycle$object {
	_jc_soot_jimple_spark_solver_PropCycle$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropCycle$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropCycle$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropCycle$vtype _jc_soot_jimple_spark_solver_PropCycle$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropCycle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropCycle$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropCycle_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/PropCycle.h <==
// public final class soot.jimple.spark.solver.PropCycle

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 12e738d2eaa79a15 soot_jimple_spark_solver_PropCycle
// @dep_class ba679de9a7cc1f7a soot_jimple_spark_solver_Propagator

// header file dependencies
// @dep_header soot_jimple_spark_solver_Propagator

#include "soot/jimple/spark/solver/Propagator.h"

#ifndef _JC_soot_jimple_spark_solver_PropCycle_H_
#define _JC_soot_jimple_spark_solver_PropCycle_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Integer$object;
struct _jc_java_util_ArrayList$object;
struct _jc_soot_jimple_spark_internal_TypeManager$object;
struct _jc_soot_jimple_spark_pag_PAG$object;
struct _jc_soot_jimple_spark_pag_VarNode$object;
struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object;
struct _jc_soot_jimple_spark_solver_PropCycle$object;
struct _jc_soot_util_LargeNumberedMap$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropCycle$sub_refs	_jc_soot_jimple_spark_solver_PropCycle$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs	_jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$refs	_jc_soot_jimple_spark_solver_PropCycle$refs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$nonrefs	_jc_soot_jimple_spark_solver_PropCycle$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropCycle$object	_jc_soot_jimple_spark_solver_PropCycle$object;

typedef const struct _jc_soot_jimple_spark_solver_PropCycle$vmethods	_jc_soot_jimple_spark_solver_PropCycle$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropCycle$vtable	_jc_soot_jimple_spark_solver_PropCycle$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropCycle$vtype	_jc_soot_jimple_spark_solver_PropCycle$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropCycle$method$_init$d432acd4fd080ea1(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *, struct _jc_soot_jimple_spark_pag_PAG$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_spark_solver_PropCycle$method$computeP2Set$16456f168b4b3df5(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_spark_solver_PropCycle$method$propagate$430f3309bbb43666(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropCycle$method_info$computeP2Set$16456f168b4b3df5;
extern _jc_method _jc_soot_jimple_spark_solver_PropCycle$method_info$propagate$430f3309bbb43666;

// Static methods
extern struct _jc_soot_jimple_spark_pag_PAG$object *_jc_soot_jimple_spark_solver_PropCycle$method$access__24000$801edc7b9b5ca5ed(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropCycle$vmethods {
	jboolean	(*computeP2Set$16456f168b4b3df5)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *, struct _jc_soot_jimple_spark_pag_VarNode$object *, struct _jc_java_util_ArrayList$object *) _JC_JCNI_ATTR;
	void	(*propagate$430f3309bbb43666)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropCycle$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropCycle$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_solver_Propagator$vmethods	soot_jimple_spark_solver_Propagator;
	_jc_soot_jimple_spark_solver_PropCycle$vmethods	soot_jimple_spark_solver_PropCycle;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropCycle$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropCycle$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropCycle$sub_refs {
	struct _jc_soot_jimple_spark_pag_PAG$object	*pag;
	struct _jc_soot_jimple_spark_solver_OnFlyCallGraph$object	*ofcg;
	struct _jc_java_lang_Integer$object	*currentIteration;
	struct _jc_soot_util_LargeNumberedMap$object	*varNodeToIteration;
	struct _jc_soot_jimple_spark_internal_TypeManager$object	*typeManager;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropCycle$refs {
    _jc_soot_jimple_spark_solver_PropCycle$sub_refs	soot_jimple_spark_solver_PropCycle;
    _jc_soot_jimple_spark_solver_Propagator$sub_refs	soot_jimple_spark_solver_Propagator;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropCycle$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_solver_Propagator$sub_nonrefs	soot_jimple_spark_solver_Propagator;
    _jc_soot_jimple_spark_solver_PropCycle$sub_nonrefs	soot_jimple_spark_solver_PropCycle;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropCycle$object {
	_jc_soot_jimple_spark_solver_PropCycle$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropCycle$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropCycle$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropCycle$vtype _jc_soot_jimple_spark_solver_PropCycle$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropCycle, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropCycle$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropCycle_H_ */
